/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.common.spi.resource;

import com.liferay.petra.function.UnsafeFunction;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.security.auth.PrincipalException;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.ratings.kernel.model.RatingsEntry;
import com.liferay.ratings.kernel.service.RatingsEntryLocalService;

/**
 * @author Javier Gamarra
 */
public class SPIRatingResource<T> {

	public SPIRatingResource(
		String className, RatingsEntryLocalService ratingsEntryLocalService,
		UnsafeFunction<RatingsEntry, T, Exception> transformUnsafeFunction,
		User user) {

		_className = className;
		_ratingsEntryLocalService = ratingsEntryLocalService;
		_transformUnsafeFunction = transformUnsafeFunction;
		_user = user;
	}

	public T addOrUpdateRating(Number ratingValue, long classPK)
		throws Exception {

		_checkPermission();

		return _transformUnsafeFunction.apply(
			_ratingsEntryLocalService.updateEntry(
				_user.getUserId(), _className, classPK,
				GetterUtil.getDouble(ratingValue), new ServiceContext()));
	}

	public void deleteRating(Long classPK) throws Exception {
		_checkPermission();

		_ratingsEntryLocalService.deleteEntry(
			_user.getUserId(), _className, classPK);
	}

	public T getRating(Long classPK) throws Exception {
		return _transformUnsafeFunction.apply(
			_ratingsEntryLocalService.getEntry(
				_user.getUserId(), _className, classPK));
	}

	private void _checkPermission() throws Exception {
		if (_user.isDefaultUser()) {
			throw new PrincipalException();
		}
	}

	private final String _className;
	private final RatingsEntryLocalService _ratingsEntryLocalService;
	private final UnsafeFunction<RatingsEntry, T, Exception>
		_transformUnsafeFunction;
	private final User _user;

}